| as.vf | R Documentation |
Coerce objects to a virtual function. Numeric or complex arguments are coerced to a constant function.
as.vf(x)
x |
Generally, a function or numeric |
Returns an object of class vf.
It is rarely necessary to coerce objects such as vectors or matrices
to class vf because the Arith methods operate on objects of
class ANY directly.
Robin K. S. Hankin
as.vf(\(x)x^2)
Sin + as.vf(\(p){p^3})
as.vf(1:10)(1e99)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.